==> konduto-sdk-0.1.0.tar.gz: konduto-sdk-0.1.0/README.md <==
<img src="https://user-images.githubusercontent.com/9020828/78465897-9a77b400-76d1-11ea-9551-1a4db4b1a910.png" align="left" width="192px" height="192px"/>
<img align="left" width="0" height="192px" hspace="10"/>

[![codecov](https://codecov.io/gh/alefhsousa/konduto-sdk/branch/master/graph/badge.svg)](https://codecov.io/gh/alefhsousa/konduto-sdk)
![ci](https://github.com/alefhsousa/konduto-sdk/workflows/ci/badge.svg)
<a href="https://github.com/alefhsousa/konduto-sdk/blob/master/LICENSE"><img alt="License: MIT" src="https://img.shields.io/github/license/alefhsousa/konduto-sdk"></a>
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/57e4534797c7416b86c20c4ec5d53067)](https://www.codacy.com/manual/alefhsousa/konduto-sdk?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=alefhsousa/konduto-sdk&amp;utm_campaign=Badge_Grade)
A Python SDK for integrating with the [Konduto rest api][1]. Compatible with python 3.6+, this repo not is a official repository from Konduto.
Feel free to contribute with the project.

### Getting Started

Setup a local environment:

I expected that you already python3 installed in your machine

```bash
$ make setup
```

### Running tests
The CI command that setups all requirements and runs tests to assure everything is configured accordingly.

```bash
$ make test
```

### License

Copyright Alefh Sousa 2020.

Distributed under the terms of the [MIT][2] license, konduto-sdk is free and open source software.

[1]: http://docs.konduto.com/en/
[2]: https://github.com/alefhsousa/konduto-sdk/blob/master/LICENSE

==> konduto-sdk-0.2.0.tar.gz: konduto-sdk-0.2.0/README.md <==
<img src="https://user-images.githubusercontent.com/9020828/78465897-9a77b400-76d1-11ea-9551-1a4db4b1a910.png" align="left" width="192px" height="192px"/>
<img align="left" width="0" height="192px" hspace="10"/>

[![codecov](https://codecov.io/gh/alefhsousa/konduto-sdk/branch/master/graph/badge.svg)](https://codecov.io/gh/alefhsousa/konduto-sdk)
![ci](https://github.com/alefhsousa/konduto-sdk/workflows/ci/badge.svg)
![PyPI - License](https://img.shields.io/pypi/l/konduto-sdk)
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/57e4534797c7416b86c20c4ec5d53067)](https://www.codacy.com/manual/alefhsousa/konduto-sdk?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=alefhsousa/konduto-sdk&amp;utm_campaign=Badge_Grade)
![PyPI - Status](https://img.shields.io/pypi/status/konduto-sdk)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/konduto-sdk)
![PyPI](https://img.shields.io/pypi/v/konduto-sdk)

A Python SDK for integrating with the [Konduto rest api][1]. Compatible with python 3.6+, this repo not is a official repository from Konduto.
Feel free to contribute with the project.

### Getting Started

Setup a local environment:

I expected that you already python3 installed in your machine

```bash
$ make setup
```

### Running tests
The CI command that setups all requirements and runs tests to assure everything is configured accordingly.

```bash
$ make test
```

### License

Copyright Alefh Sousa 2020.

Distributed under the terms of the [MIT][2] license, konduto-sdk is free and open source software.

[1]: http://docs.konduto.com/en/
[2]: https://github.com/alefhsousa/konduto-sdk/blob/master/LICENSE
